@@ -1,11 +1,11 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: shake
-version: 0.15.5
-id: shake-0.15.5-06f84b373083421f279135bc4a7142ab
-key: shake_LhOayyry8VXGKv67LcJmMi
+version: 0.15.6
+id: shake-0.15.6-a15be5151c7315dc87a691cbcd6435f3
+key: shake_DSDr9MX1PoSBT0lpTJhoUO
 license: BSD3
-copyright: Neil Mitchell 2011-2015
+copyright: Neil Mitchell 2011-2016
 maintainer: Neil Mitchell <ndmitchell@gmail.com>
 homepage: http://shakebuild.com
 synopsis: Build system library, like Make, but more accurate dependencies.
@@ -35,43 +35,42 @@ exposed: True
 exposed-modules:
     Development.Shake Development.Shake.Classes
     Development.Shake.Command Development.Shake.Config
-    Development.Shake.FilePath Development.Shake.Rule
-    Development.Shake.Util
+    Development.Shake.FilePath Development.Shake.Forward
+    Development.Shake.Rule Development.Shake.Util
 hidden-modules: Development.Ninja.Env Development.Ninja.Lexer
                 Development.Ninja.Parse Development.Ninja.Type
                 Development.Shake.Args Development.Shake.ByteString
-                Development.Shake.Core Development.Shake.Database
-                Development.Shake.Demo Development.Shake.Derived
-                Development.Shake.Errors Development.Shake.FileInfo
-                Development.Shake.FilePattern Development.Shake.Monad
-                Development.Shake.Pool Development.Shake.Profile
-                Development.Shake.Progress Development.Shake.Resource
-                Development.Shake.Rules.Directory Development.Shake.Rules.File
-                Development.Shake.Rules.Files Development.Shake.Rules.Oracle
-                Development.Shake.Rules.OrderOnly Development.Shake.Rules.Rerun
-                Development.Shake.Shake Development.Shake.Special
-                Development.Shake.Storage Development.Shake.Types
-                Development.Shake.Value General.Bilist General.Binary
-                General.Cleanup General.Concurrent General.Extra General.Intern
-                General.Process General.String General.Template General.Timing
-                Paths_shake
+                Development.Shake.Core Development.Shake.CmdOption
+                Development.Shake.Database Development.Shake.Demo
+                Development.Shake.Derived Development.Shake.Errors
+                Development.Shake.FileInfo Development.Shake.FilePattern
+                Development.Shake.Monad Development.Shake.Pool
+                Development.Shake.Profile Development.Shake.Progress
+                Development.Shake.Resource Development.Shake.Rules.Directory
+                Development.Shake.Rules.File Development.Shake.Rules.Files
+                Development.Shake.Rules.Oracle Development.Shake.Rules.OrderOnly
+                Development.Shake.Rules.Rerun Development.Shake.Shake
+                Development.Shake.Special Development.Shake.Storage
+                Development.Shake.Types Development.Shake.Value General.Bilist
+                General.Binary General.Cleanup General.Concurrent General.Extra
+                General.FileLock General.Intern General.Process General.String
+                General.Template General.Timing Paths_shake
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/shake-0.15.5
-library-dirs: /usr/lib/ghc-7.10.3/site-local/shake-0.15.5
-data-dir: /usr/share/arm-linux-ghc-7.10.3/shake-0.15.5
-hs-libraries: HSshake-0.15.5-LhOayyry8VXGKv67LcJmMi
+import-dirs: /usr/lib/ghc-7.10.3/site-local/shake-0.15.6
+library-dirs: /usr/lib/ghc-7.10.3/site-local/shake-0.15.6
+data-dir: /usr/share/arm-linux-ghc-7.10.3/shake-0.15.6
+hs-libraries: HSshake-0.15.6-DSDr9MX1PoSBT0lpTJhoUO
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    extra-1.4.3-ab419342055a04bda9f8a7a264d348c1
+    extra-1.4.6-bd6c06cb9c31ba2a6069a7f244dac489
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
     js-flot-0.8.3-f4527abded51f454b66546bc733ec63f
-    js-jquery-1.12.2-60fc2af6d883a5909b2d58515558f582
-    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
+    js-jquery-1.12.3-5118b3168089907b4a923302e26b97c5
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
